@@ -1,5 +1,6 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
+from __future__ import division
 import datetime
 from dateutil.relativedelta import relativedelta
 import itertools
@@ -102,17 +103,17 @@ class Forecast(Workflow, ModelSQL, ModelView):
     def __register__(cls, module_name):
         Location = Pool().get('stock.location')
         TableHandler = backend.get('TableHandler')
-        cursor = Transaction().cursor
+        cursor = Transaction().connection.cursor()
         sql_table = cls.__table__()
 
-        table = TableHandler(cursor, cls, module_name)
+        table = TableHandler(cls, module_name)
         migrate_warehouse = (not table.column_exist('warehouse')
             and table.column_exist('location'))
 
         super(Forecast, cls).__register__(module_name)
 
         # Add index on create_date
-        table = TableHandler(cursor, cls, module_name)
+        table = TableHandler(cls, module_name)
         table.index_action('create_date', action='add')
 
         if migrate_warehouse:
@@ -193,7 +194,7 @@ class Forecast(Workflow, ModelSQL, ModelView):
             forecast.check_date_overlap()
 
     def check_date_overlap(self):
-        cursor = Transaction().cursor
+        cursor = Transaction().connection.cursor()
         if self.state != 'done':
             return
         forcast = self.__table__()
@@ -361,7 +362,7 @@ class ForecastLine(ModelSQL, ModelView):
 
     @classmethod
     def get_quantity_executed(cls, lines, name):
-        cursor = Transaction().cursor
+        cursor = Transaction().connection.cursor()
         pool = Pool()
         Move = pool.get('stock.move')
         Location = pool.get('stock.location')
@@ -435,8 +436,8 @@ class ForecastLine(ModelSQL, ModelView):
 
         delta = to_date - from_date
         delta = delta.days + 1
-        nb_packet = int((self.quantity - self.quantity_executed)
-            / self.minimal_quantity)
+        nb_packet = ((self.quantity - self.quantity_executed)
+            // self.minimal_quantity)
         distribution = self.distribute(delta, nb_packet)
         unit_price = None
         if self.forecast.destination.type == 'customer':
@@ -484,7 +485,7 @@ class ForecastLine(ModelSQL, ModelView):
             elif delta // qty > 1:
                 i = 0
                 while i < qty:
-                    a[i * delta // qty + (delta // qty / 2)] += 1
+                    a[i * delta // qty + (delta // qty // 2)] += 1
                     i += 1
                 qty = 0
             else:
@@ -493,7 +494,7 @@ class ForecastLine(ModelSQL, ModelView):
                 qty = delta - qty
                 i = 0
                 while i < qty:
-                    a[delta - ((i * delta // qty) + (delta // qty / 2)) - 1
+                    a[delta - ((i * delta // qty) + (delta // qty // 2)) - 1
                         ] -= 1
                     i += 1
                 qty = 0
